{
    "$graph": [
        {
            "class": "CommandLineTool",
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "File",
                        {
                            "type": "array",
                            "items": "File"
                        }
                    ],
                    "inputBinding": {
                        "position": 2
                    },
                    "id": "#custom-bash.cwl/input_file"
                },
                {
                    "type": [
                        "null",
                        "string",
                        {
                            "type": "array",
                            "items": "string"
                        }
                    ],
                    "inputBinding": {
                        "position": 3
                    },
                    "id": "#custom-bash.cwl/param"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cat \"$0\" | grep \"$1\" | sed \"s/$1//g\"  > `basename $0`\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#custom-bash.cwl/script"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool to run custom script set as `script` input with arguments from `param`.\nDefault script runs sed command over the input file and exports results to the file with the same name as input's basename\n",
            "id": "#custom-bash.cwl",
            "http://schema.org/name": "custom-bash",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/custom-bash.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:michael.kotliar@cchmc.org",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "id": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "Custom bash script runner",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "id": "#custom-bash.cwl/output_file"
                }
            ]
        },
        {
            "class": "ExpressionTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "id": "#files-to-folder.cwl",
            "inputs": [
                {
                    "type": [
                        {
                            "type": "array",
                            "items": "File"
                        },
                        "File"
                    ],
                    "id": "#files-to-folder.cwl/files_to_folder/input_files"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "id": "#files-to-folder.cwl/files_to_folder/folder"
                }
            ],
            "expression": "${\n  var folder = {\n    \"class\": \"Directory\",\n    \"basename\": \"\",\n    \"listing\": []\n  }\n  var files = [];\n  if (!Array.isArray(inputs.input_files)){\n    files.push (inputs.input_files)\n  } else {\n    files = inputs.input_files\n  }\n  for (var i = 0; i < files.length; i++){\n    if (files[i].secondaryFiles && files[i].secondaryFiles.length > 0){\n      Array.prototype.push.apply(folder.listing, files[i].secondaryFiles);\n      delete files[i].secondaryFiles;\n    }\n    folder.listing.push (files[i])\n  }\n  return { \"folder\": folder };\n}\n",
            "doc": "Returns Directory object with a listing set from File or File[]. Only one nested level of secondaryFiles\nis supported"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/gseapy:v0.0.1"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "inputBinding": {
                        "prefix": "-a"
                    },
                    "doc": "Ascending rank metric sorting order. Default: False",
                    "id": "#gseapy.cwl/ascending_rank_sorting"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "name": "#gseapy.cwl/gene_set_database/genesetdatabase",
                            "symbols": [
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ARCHS4_Cell-lines",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ARCHS4_IDG_Coexp",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ARCHS4_Kinases_Coexp",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ARCHS4_TFs_Coexp",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ARCHS4_Tissues",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Achilles_fitness_decrease",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Achilles_fitness_increase",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Aging_Perturbations_from_GEO_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Aging_Perturbations_from_GEO_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Allen_Brain_Atlas_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Allen_Brain_Atlas_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/BioCarta_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/BioCarta_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/BioCarta_2016",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/BioPlanet_2019",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/BioPlex_2017",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/CCLE_Proteomics_2020",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/CORUM",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Cancer_Cell_Line_Encyclopedia",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ChEA_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ChEA_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ChEA_2016",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Chromosome_Location",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Chromosome_Location_hg19",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ClinVar_2019",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/DSigDB",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Data_Acquisition_Method_Most_Popular_Genes",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/DepMap_WG_CRISPR_Screens_Broad_CellLines_2019",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/DepMap_WG_CRISPR_Screens_Sanger_CellLines_2019",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/DisGeNET",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Disease_Perturbations_from_GEO_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Disease_Perturbations_from_GEO_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Disease_Signatures_from_GEO_down_2014",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Disease_Signatures_from_GEO_up_2014",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/DrugMatrix",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Drug_Perturbations_from_GEO_2014",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Drug_Perturbations_from_GEO_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Drug_Perturbations_from_GEO_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ENCODE_Histone_Modifications_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ENCODE_Histone_Modifications_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ENCODE_TF_ChIP-seq_2014",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ENCODE_TF_ChIP-seq_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ENCODE_and_ChEA_Consensus_TFs_from_ChIP-X",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ESCAPE",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Elsevier_Pathway_Collection",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Enrichr_Libraries_Most_Popular_Genes",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Enrichr_Submissions_TF-Gene_Coocurrence",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Epigenomics_Roadmap_HM_ChIP-seq",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Biological_Process_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Biological_Process_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Biological_Process_2017",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Biological_Process_2017b",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Biological_Process_2018",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Cellular_Component_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Cellular_Component_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Cellular_Component_2017",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Cellular_Component_2017b",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Cellular_Component_2018",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Molecular_Function_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Molecular_Function_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Molecular_Function_2017",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Molecular_Function_2017b",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GO_Molecular_Function_2018",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GTEx_Tissue_Sample_Gene_Expression_Profiles_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GTEx_Tissue_Sample_Gene_Expression_Profiles_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GWAS_Catalog_2019",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/GeneSigDB",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Gene_Perturbations_from_GEO_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Gene_Perturbations_from_GEO_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Genes_Associated_with_NIH_Grants",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Genome_Browser_PWMs",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/HMDB_Metabolites",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/HMS_LINCS_KinomeScan",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/HomoloGene",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/HumanCyc_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/HumanCyc_2016",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Human_Gene_Atlas",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Human_Phenotype_Ontology",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/InterPro_Domains_2019",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Jensen_COMPARTMENTS",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Jensen_DISEASES",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Jensen_TISSUES",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/KEA_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/KEA_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/KEGG_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/KEGG_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/KEGG_2016",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/KEGG_2019_Human",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/KEGG_2019_Mouse",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Kinase_Perturbations_from_GEO_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Kinase_Perturbations_from_GEO_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/L1000_Kinase_and_GPCR_Perturbations_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/L1000_Kinase_and_GPCR_Perturbations_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/LINCS_L1000_Chem_Pert_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/LINCS_L1000_Chem_Pert_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/LINCS_L1000_Ligand_Perturbations_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/LINCS_L1000_Ligand_Perturbations_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Ligand_Perturbations_from_GEO_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Ligand_Perturbations_from_GEO_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/MCF7_Perturbations_from_GEO_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/MCF7_Perturbations_from_GEO_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/MGI_Mammalian_Phenotype_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/MGI_Mammalian_Phenotype_2017",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/MGI_Mammalian_Phenotype_Level_3",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/MGI_Mammalian_Phenotype_Level_4",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/MGI_Mammalian_Phenotype_Level_4_2019",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/MSigDB_Computational",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/MSigDB_Oncogenic_Signatures",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Microbe_Perturbations_from_GEO_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Microbe_Perturbations_from_GEO_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Mouse_Gene_Atlas",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/NCI-60_Cancer_Cell_Lines",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/NCI-Nature_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/NCI-Nature_2016",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/NIH_Funded_PIs_2017_AutoRIF_ARCHS4_Predictions",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/NIH_Funded_PIs_2017_GeneRIF_ARCHS4_Predictions",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/NIH_Funded_PIs_2017_Human_AutoRIF",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/NIH_Funded_PIs_2017_Human_GeneRIF",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/NURSA_Human_Endogenous_Complexome",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/OMIM_Disease",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/OMIM_Expanded",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Old_CMAP_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Old_CMAP_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/PPI_Hub_Proteins",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Panther_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Panther_2016",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Pfam_Domains_2019",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Pfam_InterPro_Domains",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/PheWeb_2019",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Phosphatase_Substrates_from_DEPOD",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/ProteomicsDB_2020",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/RNA-Seq_Disease_Gene_and_Drug_Signatures_from_GEO",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Rare_Diseases_AutoRIF_ARCHS4_Predictions",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Rare_Diseases_AutoRIF_Gene_Lists",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Rare_Diseases_GeneRIF_ARCHS4_Predictions",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Rare_Diseases_GeneRIF_Gene_Lists",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Reactome_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Reactome_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Reactome_2016",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/SILAC_Phosphoproteomics",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/SubCell_BarCode",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/SysMyo_Muscle_Gene_Sets",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/TF-LOF_Expression_from_GEO",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/TF_Perturbations_Followed_by_Expression",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/TRANSFAC_and_JASPAR_PWMs",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/TRRUST_Transcription_Factors_2019",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Table_Mining_of_CRISPR_Studies",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/TargetScan_microRNA",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/TargetScan_microRNA_2017",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Tissue_Protein_Expression_from_Human_Proteome_Map",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Tissue_Protein_Expression_from_ProteomicsDB",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Transcription_Factor_PPIs",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/UK_Biobank_GWAS_v1",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Virus-Host_PPI_P-HIPSTer_2020",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/VirusMINT",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Virus_Perturbations_from_GEO_down",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/Virus_Perturbations_from_GEO_up",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/WikiPathways_2013",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/WikiPathways_2015",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/WikiPathways_2016",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/WikiPathways_2019_Human",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/WikiPathways_2019_Mouse",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/dbGaP",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/huMAP",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/lncHUB_lncRNA_Co-Expression",
                                "#gseapy.cwl/gene_set_database/genesetdatabase/miRTarBase_2017"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-g"
                    },
                    "doc": "Gene set database",
                    "id": "#gseapy.cwl/gene_set_database"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--graph"
                    },
                    "doc": "Numbers of top graphs produced. Default: 20",
                    "id": "#gseapy.cwl/graphs_count"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--max-size"
                    },
                    "doc": "Max size of input genes presented in Gene Sets. Default: 500",
                    "id": "#gseapy.cwl/max_gene_set_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "--min-size"
                    },
                    "doc": "Min size of input genes presented in Gene Sets. Default: 15",
                    "id": "#gseapy.cwl/min_gene_set_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-n"
                    },
                    "doc": "Number of random permutations. For calculating esnulls. Default: 1000",
                    "id": "#gseapy.cwl/permutation_count"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#gseapy.cwl/permutation_type/permutationtype",
                            "symbols": [
                                "#gseapy.cwl/permutation_type/permutationtype/gene_set",
                                "#gseapy.cwl/permutation_type/permutationtype/phenotype"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-t"
                    },
                    "doc": "Permutation type. Default: gene_set",
                    "id": "#gseapy.cwl/permutation_type"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-c"
                    },
                    "doc": "Input class vector (phenotype) file in CLS format. Same with GSEA",
                    "id": "#gseapy.cwl/phenotypes_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#gseapy.cwl/ranking_metrics/rankingmetrics",
                            "symbols": [
                                "#gseapy.cwl/ranking_metrics/rankingmetrics/signal_to_noise",
                                "#gseapy.cwl/ranking_metrics/rankingmetrics/t_test",
                                "#gseapy.cwl/ranking_metrics/rankingmetrics/ratio_of_classes",
                                "#gseapy.cwl/ranking_metrics/rankingmetrics/diff_of_classes",
                                "#gseapy.cwl/ranking_metrics/rankingmetrics/log2_ratio_of_classes"
                            ]
                        }
                    ],
                    "inputBinding": {
                        "prefix": "-m"
                    },
                    "doc": "Methods to calculate correlations of ranking metrics. Default: log2_ratio_of_classes",
                    "id": "#gseapy.cwl/ranking_metrics"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-d"
                    },
                    "doc": "Input gene expression dataset file in txt or gct format. Same with GSEA",
                    "id": "#gseapy.cwl/read_counts_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-s"
                    },
                    "doc": "Number of random seed. Default: None",
                    "id": "#gseapy.cwl/seed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "inputBinding": {
                        "prefix": "-p"
                    },
                    "doc": "Threads number",
                    "id": "#gseapy.cwl/threads"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "GSEApy_reports/*.heatmap.pdf"
                    },
                    "id": "#gseapy.cwl/enrichment_heatmaps"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "GSEApy_reports/*.gsea.pdf"
                    },
                    "id": "#gseapy.cwl/enrichment_plots"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "outputBinding": {
                        "glob": "GSEApy_reports/*.report.csv"
                    },
                    "id": "#gseapy.cwl/enrichment_report"
                },
                {
                    "type": "File",
                    "id": "#gseapy.cwl/stderr_log",
                    "outputBinding": {
                        "glob": "gseapy_stderr.log"
                    }
                },
                {
                    "type": "File",
                    "id": "#gseapy.cwl/stdout_log",
                    "outputBinding": {
                        "glob": "gseapy_stdout.log"
                    }
                }
            ],
            "baseCommand": [
                "gseapy",
                "gsea"
            ],
            "stdout": "gseapy_stdout.log",
            "stderr": "gseapy_stderr.log",
            "doc": "GSEAPY: Gene Set Enrichment Analysis in Python\n==============================================\n\nGene Set Enrichment Analysis is a computational method that determines whether an a priori\ndefined set of genes shows statistically significant, concordant differences between two\nbiological states (e.g. phenotypes).\n\nGSEA requires as input an expression dataset, which contains expression profiles for multiple samples.\nWhile the software supports multiple input file formats for these datasets, the tab-delimited GCT format\nis the most common. The first column of the GCT file contains feature identifiers (gene ids or symbols in\nthe case of data derived from RNA-Seq experiments). The second column contains a description of the feature;\nthis column is ignored by GSEA and may be filled with \u201cNA\u201ds. Subsequent columns contain the expression\nvalues for each feature, with one sample's expression value per column. It is important to note that there\nare no hard and fast rules regarding how a GCT file's expression values are derived. The important point is\nthat they are comparable to one another across features within a sample and comparable to one another\nacross samples. Tools such as DESeq2 can be made to produce properly normalized data (normalized counts)\nwhich are compatible with GSEA.\n",
            "id": "#gseapy.cwl",
            "http://schema.org/name": "gseapy",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/gseapy.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "usage: gseapy gsea [-h] -d DATA -c CLS -g GMT [-t perType] [-o] [-f]\n                  [--fs width height] [--graph int] [--no-plot] [-v]\n                  [-n nperm] [--min-size int] [--max-size int] [-w float]\n                  [-m] [-a] [-s] [-p procs]\n\noptional arguments:\n  -h, --help            show this help message and exit\n\nInput files arguments:\n  -d DATA, --data DATA  Input gene expression dataset file in txt format.Same\n                        with GSEA.\n  -c CLS, --cls CLS     Input class vector (phenotype) file in CLS format.\n                        Same with GSEA.\n  -g GMT, --gmt GMT     Gene set database in GMT format. Same with GSEA.\n  -t perType, --permu-type perType\n                        Permutation type. Same with GSEA, choose from\n                        {'gene_set', 'phenotype'}\n\nOutput arguments:\n  -o , --outdir         The GSEApy output directory. Default: the current\n                        working directory\n  -f , --format         File extensions supported by Matplotlib active\n                        backend, choose from {'pdf', 'png', 'jpeg','ps',\n                        'eps','svg'}. Default: 'pdf'.\n  --fs width height, --figsize width height\n                        The figsize keyword argument need two parameters to\n                        define. Default: (6.5, 6)\n  --graph int           Numbers of top graphs produced. Default: 20\n  --no-plot             Speed up computing by suppressing the plot output.This\n                        is useful only if data are interested. Default: False.\n  -v, --verbose         Increase output verbosity, print out progress of your\n                        job\n\nGSEA advanced arguments:\n  -n nperm, --permu-num nperm\n                        Number of random permutations. For calculating\n                        esnulls. Default: 1000\n  --min-size int        Min size of input genes presented in Gene Sets.\n                        Default: 15\n  --max-size int        Max size of input genes presented in Gene Sets.\n                        Default: 500\n  -w float, --weight float\n                        Weighted_score of rank_metrics. For weighting input\n                        genes. Choose from {0, 1, 1.5, 2}. Default: 1\n  -m , --method         Methods to calculate correlations of ranking metrics.\n                        Choose from {'signal_to_noise', 't_test',\n                        'ratio_of_classes',\n                        'diff_of_classes','log2_ratio_of_classes'}. Default:\n                        'log2_ratio_of_classes'\n  -a, --ascending       Rank metric sorting order. If the -a flag was chosen,\n                        then ascending equals to True. Default: False.\n  -s , --seed           Number of random seed. Default: None\n  -p procs, --threads procs\n                        Number of Processes you are going to use. Default: 1"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "var get_target_name = function() { return inputs.target_filename.split('/').slice(-1)[0]; }"
                    ]
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "#!/bin/bash\ncp $0 $1\nif [ -f $0.bai ]; then\n  cp $0.bai $1.bai\nfi\n",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#rename.cwl/script"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 5
                    },
                    "id": "#rename.cwl/source_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "position": 6,
                        "valueFrom": "$(get_target_name())"
                    },
                    "id": "#rename.cwl/target_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(get_target_name())"
                    },
                    "secondaryFiles": "${\n    if (inputs.source_file.secondaryFiles && inputs.source_file.secondaryFiles.length > 0){\n      return inputs.target_filename+\".bai\";\n    } else {\n      return \"null\";\n    }\n  }\n",
                    "id": "#rename.cwl/target_file"
                }
            ],
            "baseCommand": [
                "bash",
                "-c"
            ],
            "doc": "Tool renames `source_file` to `target_filename`.\nInput `target_filename` should be set as string. If it's a full path, only basename will be used.\nIf BAI file is present, it will be renamed too\n",
            "id": "#rename.cwl",
            "http://schema.org/name": "rename",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/rename.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ],
            "http://schema.org/about": "cp source target"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "biowardrobe2/scidap:v0.0.3"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "doc": "Folder to compressed",
                    "id": "#tar-compress.cwl/folder_to_compress"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*"
                    },
                    "doc": "Compressed folder",
                    "id": "#tar-compress.cwl/compressed_folder"
                }
            ],
            "baseCommand": [
                "tar"
            ],
            "arguments": [
                {
                    "valueFrom": "$(inputs.folder_to_compress.path.split(\"/\").slice(0,-1).join(\"/\"))",
                    "prefix": "-C"
                },
                "-cvf",
                {
                    "valueFrom": "$(inputs.folder_to_compress.basename + \".tar.gz\")"
                },
                "."
            ],
            "doc": "Compresses input directory to tar.gz\n",
            "id": "#tar-compress.cwl",
            "http://schema.org/name": "tar-compress",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/Barski-lab/workflows/master/tools/tar-compress.cwl",
            "http://schema.org/codeRepository": "https://github.com/Barski-lab/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                }
            ],
            "sd:upstream": {
                "deseq_experiment": [
                    "deseq.cwl"
                ]
            },
            "inputs": [
                {
                    "type": "string",
                    "label": "Experiment short name/Alias",
                    "sd:preview": {
                        "position": 1
                    },
                    "id": "#main/alias"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "default": false,
                    "label": "Ascending rank metric sorting order",
                    "doc": "Ascending rank metric sorting order. Default: False",
                    "id": "#main/ascending_rank_sorting"
                },
                {
                    "type": [
                        {
                            "type": "enum",
                            "name": "#main/gene_set_database/genesetdatabase",
                            "symbols": [
                                "#main/gene_set_database/genesetdatabase/ARCHS4_Cell-lines",
                                "#main/gene_set_database/genesetdatabase/ARCHS4_IDG_Coexp",
                                "#main/gene_set_database/genesetdatabase/ARCHS4_Kinases_Coexp",
                                "#main/gene_set_database/genesetdatabase/ARCHS4_TFs_Coexp",
                                "#main/gene_set_database/genesetdatabase/ARCHS4_Tissues",
                                "#main/gene_set_database/genesetdatabase/Achilles_fitness_decrease",
                                "#main/gene_set_database/genesetdatabase/Achilles_fitness_increase",
                                "#main/gene_set_database/genesetdatabase/Aging_Perturbations_from_GEO_down",
                                "#main/gene_set_database/genesetdatabase/Aging_Perturbations_from_GEO_up",
                                "#main/gene_set_database/genesetdatabase/Allen_Brain_Atlas_down",
                                "#main/gene_set_database/genesetdatabase/Allen_Brain_Atlas_up",
                                "#main/gene_set_database/genesetdatabase/BioCarta_2013",
                                "#main/gene_set_database/genesetdatabase/BioCarta_2015",
                                "#main/gene_set_database/genesetdatabase/BioCarta_2016",
                                "#main/gene_set_database/genesetdatabase/BioPlanet_2019",
                                "#main/gene_set_database/genesetdatabase/BioPlex_2017",
                                "#main/gene_set_database/genesetdatabase/CCLE_Proteomics_2020",
                                "#main/gene_set_database/genesetdatabase/CORUM",
                                "#main/gene_set_database/genesetdatabase/Cancer_Cell_Line_Encyclopedia",
                                "#main/gene_set_database/genesetdatabase/ChEA_2013",
                                "#main/gene_set_database/genesetdatabase/ChEA_2015",
                                "#main/gene_set_database/genesetdatabase/ChEA_2016",
                                "#main/gene_set_database/genesetdatabase/Chromosome_Location",
                                "#main/gene_set_database/genesetdatabase/Chromosome_Location_hg19",
                                "#main/gene_set_database/genesetdatabase/ClinVar_2019",
                                "#main/gene_set_database/genesetdatabase/DSigDB",
                                "#main/gene_set_database/genesetdatabase/Data_Acquisition_Method_Most_Popular_Genes",
                                "#main/gene_set_database/genesetdatabase/DepMap_WG_CRISPR_Screens_Broad_CellLines_2019",
                                "#main/gene_set_database/genesetdatabase/DepMap_WG_CRISPR_Screens_Sanger_CellLines_2019",
                                "#main/gene_set_database/genesetdatabase/DisGeNET",
                                "#main/gene_set_database/genesetdatabase/Disease_Perturbations_from_GEO_down",
                                "#main/gene_set_database/genesetdatabase/Disease_Perturbations_from_GEO_up",
                                "#main/gene_set_database/genesetdatabase/Disease_Signatures_from_GEO_down_2014",
                                "#main/gene_set_database/genesetdatabase/Disease_Signatures_from_GEO_up_2014",
                                "#main/gene_set_database/genesetdatabase/DrugMatrix",
                                "#main/gene_set_database/genesetdatabase/Drug_Perturbations_from_GEO_2014",
                                "#main/gene_set_database/genesetdatabase/Drug_Perturbations_from_GEO_down",
                                "#main/gene_set_database/genesetdatabase/Drug_Perturbations_from_GEO_up",
                                "#main/gene_set_database/genesetdatabase/ENCODE_Histone_Modifications_2013",
                                "#main/gene_set_database/genesetdatabase/ENCODE_Histone_Modifications_2015",
                                "#main/gene_set_database/genesetdatabase/ENCODE_TF_ChIP-seq_2014",
                                "#main/gene_set_database/genesetdatabase/ENCODE_TF_ChIP-seq_2015",
                                "#main/gene_set_database/genesetdatabase/ENCODE_and_ChEA_Consensus_TFs_from_ChIP-X",
                                "#main/gene_set_database/genesetdatabase/ESCAPE",
                                "#main/gene_set_database/genesetdatabase/Elsevier_Pathway_Collection",
                                "#main/gene_set_database/genesetdatabase/Enrichr_Libraries_Most_Popular_Genes",
                                "#main/gene_set_database/genesetdatabase/Enrichr_Submissions_TF-Gene_Coocurrence",
                                "#main/gene_set_database/genesetdatabase/Epigenomics_Roadmap_HM_ChIP-seq",
                                "#main/gene_set_database/genesetdatabase/GO_Biological_Process_2013",
                                "#main/gene_set_database/genesetdatabase/GO_Biological_Process_2015",
                                "#main/gene_set_database/genesetdatabase/GO_Biological_Process_2017",
                                "#main/gene_set_database/genesetdatabase/GO_Biological_Process_2017b",
                                "#main/gene_set_database/genesetdatabase/GO_Biological_Process_2018",
                                "#main/gene_set_database/genesetdatabase/GO_Cellular_Component_2013",
                                "#main/gene_set_database/genesetdatabase/GO_Cellular_Component_2015",
                                "#main/gene_set_database/genesetdatabase/GO_Cellular_Component_2017",
                                "#main/gene_set_database/genesetdatabase/GO_Cellular_Component_2017b",
                                "#main/gene_set_database/genesetdatabase/GO_Cellular_Component_2018",
                                "#main/gene_set_database/genesetdatabase/GO_Molecular_Function_2013",
                                "#main/gene_set_database/genesetdatabase/GO_Molecular_Function_2015",
                                "#main/gene_set_database/genesetdatabase/GO_Molecular_Function_2017",
                                "#main/gene_set_database/genesetdatabase/GO_Molecular_Function_2017b",
                                "#main/gene_set_database/genesetdatabase/GO_Molecular_Function_2018",
                                "#main/gene_set_database/genesetdatabase/GTEx_Tissue_Sample_Gene_Expression_Profiles_down",
                                "#main/gene_set_database/genesetdatabase/GTEx_Tissue_Sample_Gene_Expression_Profiles_up",
                                "#main/gene_set_database/genesetdatabase/GWAS_Catalog_2019",
                                "#main/gene_set_database/genesetdatabase/GeneSigDB",
                                "#main/gene_set_database/genesetdatabase/Gene_Perturbations_from_GEO_down",
                                "#main/gene_set_database/genesetdatabase/Gene_Perturbations_from_GEO_up",
                                "#main/gene_set_database/genesetdatabase/Genes_Associated_with_NIH_Grants",
                                "#main/gene_set_database/genesetdatabase/Genome_Browser_PWMs",
                                "#main/gene_set_database/genesetdatabase/HMDB_Metabolites",
                                "#main/gene_set_database/genesetdatabase/HMS_LINCS_KinomeScan",
                                "#main/gene_set_database/genesetdatabase/HomoloGene",
                                "#main/gene_set_database/genesetdatabase/HumanCyc_2015",
                                "#main/gene_set_database/genesetdatabase/HumanCyc_2016",
                                "#main/gene_set_database/genesetdatabase/Human_Gene_Atlas",
                                "#main/gene_set_database/genesetdatabase/Human_Phenotype_Ontology",
                                "#main/gene_set_database/genesetdatabase/InterPro_Domains_2019",
                                "#main/gene_set_database/genesetdatabase/Jensen_COMPARTMENTS",
                                "#main/gene_set_database/genesetdatabase/Jensen_DISEASES",
                                "#main/gene_set_database/genesetdatabase/Jensen_TISSUES",
                                "#main/gene_set_database/genesetdatabase/KEA_2013",
                                "#main/gene_set_database/genesetdatabase/KEA_2015",
                                "#main/gene_set_database/genesetdatabase/KEGG_2013",
                                "#main/gene_set_database/genesetdatabase/KEGG_2015",
                                "#main/gene_set_database/genesetdatabase/KEGG_2016",
                                "#main/gene_set_database/genesetdatabase/KEGG_2019_Human",
                                "#main/gene_set_database/genesetdatabase/KEGG_2019_Mouse",
                                "#main/gene_set_database/genesetdatabase/Kinase_Perturbations_from_GEO_down",
                                "#main/gene_set_database/genesetdatabase/Kinase_Perturbations_from_GEO_up",
                                "#main/gene_set_database/genesetdatabase/L1000_Kinase_and_GPCR_Perturbations_down",
                                "#main/gene_set_database/genesetdatabase/L1000_Kinase_and_GPCR_Perturbations_up",
                                "#main/gene_set_database/genesetdatabase/LINCS_L1000_Chem_Pert_down",
                                "#main/gene_set_database/genesetdatabase/LINCS_L1000_Chem_Pert_up",
                                "#main/gene_set_database/genesetdatabase/LINCS_L1000_Ligand_Perturbations_down",
                                "#main/gene_set_database/genesetdatabase/LINCS_L1000_Ligand_Perturbations_up",
                                "#main/gene_set_database/genesetdatabase/Ligand_Perturbations_from_GEO_down",
                                "#main/gene_set_database/genesetdatabase/Ligand_Perturbations_from_GEO_up",
                                "#main/gene_set_database/genesetdatabase/MCF7_Perturbations_from_GEO_down",
                                "#main/gene_set_database/genesetdatabase/MCF7_Perturbations_from_GEO_up",
                                "#main/gene_set_database/genesetdatabase/MGI_Mammalian_Phenotype_2013",
                                "#main/gene_set_database/genesetdatabase/MGI_Mammalian_Phenotype_2017",
                                "#main/gene_set_database/genesetdatabase/MGI_Mammalian_Phenotype_Level_3",
                                "#main/gene_set_database/genesetdatabase/MGI_Mammalian_Phenotype_Level_4",
                                "#main/gene_set_database/genesetdatabase/MGI_Mammalian_Phenotype_Level_4_2019",
                                "#main/gene_set_database/genesetdatabase/MSigDB_Computational",
                                "#main/gene_set_database/genesetdatabase/MSigDB_Oncogenic_Signatures",
                                "#main/gene_set_database/genesetdatabase/Microbe_Perturbations_from_GEO_down",
                                "#main/gene_set_database/genesetdatabase/Microbe_Perturbations_from_GEO_up",
                                "#main/gene_set_database/genesetdatabase/Mouse_Gene_Atlas",
                                "#main/gene_set_database/genesetdatabase/NCI-60_Cancer_Cell_Lines",
                                "#main/gene_set_database/genesetdatabase/NCI-Nature_2015",
                                "#main/gene_set_database/genesetdatabase/NCI-Nature_2016",
                                "#main/gene_set_database/genesetdatabase/NIH_Funded_PIs_2017_AutoRIF_ARCHS4_Predictions",
                                "#main/gene_set_database/genesetdatabase/NIH_Funded_PIs_2017_GeneRIF_ARCHS4_Predictions",
                                "#main/gene_set_database/genesetdatabase/NIH_Funded_PIs_2017_Human_AutoRIF",
                                "#main/gene_set_database/genesetdatabase/NIH_Funded_PIs_2017_Human_GeneRIF",
                                "#main/gene_set_database/genesetdatabase/NURSA_Human_Endogenous_Complexome",
                                "#main/gene_set_database/genesetdatabase/OMIM_Disease",
                                "#main/gene_set_database/genesetdatabase/OMIM_Expanded",
                                "#main/gene_set_database/genesetdatabase/Old_CMAP_down",
                                "#main/gene_set_database/genesetdatabase/Old_CMAP_up",
                                "#main/gene_set_database/genesetdatabase/PPI_Hub_Proteins",
                                "#main/gene_set_database/genesetdatabase/Panther_2015",
                                "#main/gene_set_database/genesetdatabase/Panther_2016",
                                "#main/gene_set_database/genesetdatabase/Pfam_Domains_2019",
                                "#main/gene_set_database/genesetdatabase/Pfam_InterPro_Domains",
                                "#main/gene_set_database/genesetdatabase/PheWeb_2019",
                                "#main/gene_set_database/genesetdatabase/Phosphatase_Substrates_from_DEPOD",
                                "#main/gene_set_database/genesetdatabase/ProteomicsDB_2020",
                                "#main/gene_set_database/genesetdatabase/RNA-Seq_Disease_Gene_and_Drug_Signatures_from_GEO",
                                "#main/gene_set_database/genesetdatabase/Rare_Diseases_AutoRIF_ARCHS4_Predictions",
                                "#main/gene_set_database/genesetdatabase/Rare_Diseases_AutoRIF_Gene_Lists",
                                "#main/gene_set_database/genesetdatabase/Rare_Diseases_GeneRIF_ARCHS4_Predictions",
                                "#main/gene_set_database/genesetdatabase/Rare_Diseases_GeneRIF_Gene_Lists",
                                "#main/gene_set_database/genesetdatabase/Reactome_2013",
                                "#main/gene_set_database/genesetdatabase/Reactome_2015",
                                "#main/gene_set_database/genesetdatabase/Reactome_2016",
                                "#main/gene_set_database/genesetdatabase/SILAC_Phosphoproteomics",
                                "#main/gene_set_database/genesetdatabase/SubCell_BarCode",
                                "#main/gene_set_database/genesetdatabase/SysMyo_Muscle_Gene_Sets",
                                "#main/gene_set_database/genesetdatabase/TF-LOF_Expression_from_GEO",
                                "#main/gene_set_database/genesetdatabase/TF_Perturbations_Followed_by_Expression",
                                "#main/gene_set_database/genesetdatabase/TRANSFAC_and_JASPAR_PWMs",
                                "#main/gene_set_database/genesetdatabase/TRRUST_Transcription_Factors_2019",
                                "#main/gene_set_database/genesetdatabase/Table_Mining_of_CRISPR_Studies",
                                "#main/gene_set_database/genesetdatabase/TargetScan_microRNA",
                                "#main/gene_set_database/genesetdatabase/TargetScan_microRNA_2017",
                                "#main/gene_set_database/genesetdatabase/Tissue_Protein_Expression_from_Human_Proteome_Map",
                                "#main/gene_set_database/genesetdatabase/Tissue_Protein_Expression_from_ProteomicsDB",
                                "#main/gene_set_database/genesetdatabase/Transcription_Factor_PPIs",
                                "#main/gene_set_database/genesetdatabase/UK_Biobank_GWAS_v1",
                                "#main/gene_set_database/genesetdatabase/Virus-Host_PPI_P-HIPSTer_2020",
                                "#main/gene_set_database/genesetdatabase/VirusMINT",
                                "#main/gene_set_database/genesetdatabase/Virus_Perturbations_from_GEO_down",
                                "#main/gene_set_database/genesetdatabase/Virus_Perturbations_from_GEO_up",
                                "#main/gene_set_database/genesetdatabase/WikiPathways_2013",
                                "#main/gene_set_database/genesetdatabase/WikiPathways_2015",
                                "#main/gene_set_database/genesetdatabase/WikiPathways_2016",
                                "#main/gene_set_database/genesetdatabase/WikiPathways_2019_Human",
                                "#main/gene_set_database/genesetdatabase/WikiPathways_2019_Mouse",
                                "#main/gene_set_database/genesetdatabase/dbGaP",
                                "#main/gene_set_database/genesetdatabase/huMAP",
                                "#main/gene_set_database/genesetdatabase/lncHUB_lncRNA_Co-Expression",
                                "#main/gene_set_database/genesetdatabase/miRTarBase_2017"
                            ]
                        }
                    ],
                    "default": "GeneSigDB",
                    "label": "Gene set database",
                    "doc": "Gene set database",
                    "id": "#main/gene_set_database"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 20,
                    "label": "Numbers of top graphs produced",
                    "doc": "Numbers of top graphs produced. Default: 20",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/graphs_count"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 500,
                    "label": "Max size of input genes presented in Gene Sets",
                    "doc": "Max size of input genes presented in Gene Sets. Default: 500",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/max_gene_set_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 15,
                    "label": "Min size of input genes presented in Gene Sets",
                    "doc": "Min size of input genes presented in Gene Sets. Default: 15",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/min_gene_set_size"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 1000,
                    "label": "Number of random permutations",
                    "doc": "Number of random permutations. For calculating esnulls. Default: 1000",
                    "id": "#main/permutation_count"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#main/permutation_type/permutationtype",
                            "symbols": [
                                "#main/permutation_type/permutationtype/gene_set",
                                "#main/permutation_type/permutationtype/phenotype"
                            ]
                        }
                    ],
                    "default": "gene_set",
                    "label": "Permutation type",
                    "doc": "Permutation type. Default: gene_set",
                    "id": "#main/permutation_type"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "DESeq experiment",
                    "doc": "Input class vector (phenotype) file in CLS format. Same with GSEA",
                    "sd:upstreamSource": "deseq_experiment/phenotypes_file",
                    "sd:localLabel": true,
                    "id": "#main/phenotypes_file"
                },
                {
                    "type": [
                        "null",
                        {
                            "type": "enum",
                            "name": "#main/ranking_metrics/rankingmetrics",
                            "symbols": [
                                "#main/ranking_metrics/rankingmetrics/signal_to_noise",
                                "#main/ranking_metrics/rankingmetrics/t_test",
                                "#main/ranking_metrics/rankingmetrics/ratio_of_classes",
                                "#main/ranking_metrics/rankingmetrics/diff_of_classes",
                                "#main/ranking_metrics/rankingmetrics/log2_ratio_of_classes"
                            ]
                        }
                    ],
                    "default": "signal_to_noise",
                    "label": "Methods to calculate correlations of ranking metrics",
                    "doc": "Methods to calculate correlations of ranking metrics. Default: log2_ratio_of_classes",
                    "id": "#main/ranking_metrics"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3709",
                    "label": "DESeq experiment",
                    "doc": "Input gene expression dataset file in txt or gct format. Same with GSEA",
                    "sd:upstreamSource": "deseq_experiment/read_counts_file",
                    "sd:localLabel": true,
                    "id": "#main/read_counts_file"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "label": "Number of random seed. Default: None",
                    "doc": "Number of random seed. Default: None",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/seed"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 4,
                    "label": "Number of threads",
                    "doc": "Number of threads for those steps that support multithreading",
                    "sd:layout": {
                        "advanced": true
                    },
                    "id": "#main/threads"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "label": "Compressed TAR with enrichment heatmaps",
                    "doc": "Compressed TAR with enrichment heatmaps",
                    "outputSource": "#main/rename_enrichment_heatmaps/target_file",
                    "id": "#main/gseapy_enrichment_heatmaps"
                },
                {
                    "type": "File",
                    "label": "Compressed TAR with enrichment plots",
                    "doc": "Compressed TAR with enrichment plots",
                    "outputSource": "#main/rename_enrichment_plots/target_file",
                    "id": "#main/gseapy_enrichment_plots"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_3475",
                    "label": "Enrichment report",
                    "doc": "Enrichment report",
                    "outputSource": "#main/convert_to_tsv/output_file",
                    "sd:visualPlugins": [
                        {
                            "syncfusiongrid": {
                                "tab": "Gene Set Enrichment",
                                "Title": "Gene Set Enrichment"
                            }
                        }
                    ],
                    "id": "#main/gseapy_enrichment_report"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "GSEApy stderr log",
                    "doc": "GSEApy stderr log",
                    "outputSource": "#main/run_gseapy/stderr_log",
                    "id": "#main/gseapy_stderr_log"
                },
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_2330",
                    "label": "GSEApy stdout log",
                    "doc": "GSEApy stdout log",
                    "outputSource": "#main/run_gseapy/stdout_log",
                    "id": "#main/gseapy_stdout_log"
                }
            ],
            "steps": [
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#main/enrichment_heatmaps_to_folder/folder",
                            "id": "#main/compress_enrichment_heatmaps/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#main/compress_enrichment_heatmaps/compressed_folder"
                    ],
                    "id": "#main/compress_enrichment_heatmaps"
                },
                {
                    "run": "#tar-compress.cwl",
                    "in": [
                        {
                            "source": "#main/enrichment_plots_to_folder/folder",
                            "id": "#main/compress_enrichment_plots/folder_to_compress"
                        }
                    ],
                    "out": [
                        "#main/compress_enrichment_plots/compressed_folder"
                    ],
                    "id": "#main/compress_enrichment_plots"
                },
                {
                    "run": "#custom-bash.cwl",
                    "in": [
                        {
                            "source": "#main/run_gseapy/enrichment_report",
                            "id": "#main/convert_to_tsv/input_file"
                        },
                        {
                            "default": "cat \"$0\" | tr \",\" \"\\t\" > `basename $0 csv`tsv\n",
                            "id": "#main/convert_to_tsv/script"
                        }
                    ],
                    "out": [
                        "#main/convert_to_tsv/output_file"
                    ],
                    "id": "#main/convert_to_tsv"
                },
                {
                    "run": "#files-to-folder.cwl",
                    "in": [
                        {
                            "source": "#main/run_gseapy/enrichment_heatmaps",
                            "id": "#main/enrichment_heatmaps_to_folder/input_files"
                        }
                    ],
                    "out": [
                        "#main/enrichment_heatmaps_to_folder/folder"
                    ],
                    "id": "#main/enrichment_heatmaps_to_folder"
                },
                {
                    "run": "#files-to-folder.cwl",
                    "in": [
                        {
                            "source": "#main/run_gseapy/enrichment_plots",
                            "id": "#main/enrichment_plots_to_folder/input_files"
                        }
                    ],
                    "out": [
                        "#main/enrichment_plots_to_folder/folder"
                    ],
                    "id": "#main/enrichment_plots_to_folder"
                },
                {
                    "run": "#rename.cwl",
                    "in": [
                        {
                            "source": "#main/compress_enrichment_heatmaps/compressed_folder",
                            "id": "#main/rename_enrichment_heatmaps/source_file"
                        },
                        {
                            "default": "enrichment_heatmaps.tar.gz",
                            "id": "#main/rename_enrichment_heatmaps/target_filename"
                        }
                    ],
                    "out": [
                        "#main/rename_enrichment_heatmaps/target_file"
                    ],
                    "id": "#main/rename_enrichment_heatmaps"
                },
                {
                    "run": "#rename.cwl",
                    "in": [
                        {
                            "source": "#main/compress_enrichment_plots/compressed_folder",
                            "id": "#main/rename_enrichment_plots/source_file"
                        },
                        {
                            "default": "enrichment_plots.tar.gz",
                            "id": "#main/rename_enrichment_plots/target_filename"
                        }
                    ],
                    "out": [
                        "#main/rename_enrichment_plots/target_file"
                    ],
                    "id": "#main/rename_enrichment_plots"
                },
                {
                    "run": "#gseapy.cwl",
                    "in": [
                        {
                            "source": "#main/ascending_rank_sorting",
                            "id": "#main/run_gseapy/ascending_rank_sorting"
                        },
                        {
                            "source": "#main/gene_set_database",
                            "id": "#main/run_gseapy/gene_set_database"
                        },
                        {
                            "source": "#main/graphs_count",
                            "id": "#main/run_gseapy/graphs_count"
                        },
                        {
                            "source": "#main/max_gene_set_size",
                            "id": "#main/run_gseapy/max_gene_set_size"
                        },
                        {
                            "source": "#main/min_gene_set_size",
                            "id": "#main/run_gseapy/min_gene_set_size"
                        },
                        {
                            "source": "#main/permutation_count",
                            "id": "#main/run_gseapy/permutation_count"
                        },
                        {
                            "source": "#main/permutation_type",
                            "id": "#main/run_gseapy/permutation_type"
                        },
                        {
                            "source": "#main/phenotypes_file",
                            "id": "#main/run_gseapy/phenotypes_file"
                        },
                        {
                            "source": "#main/ranking_metrics",
                            "id": "#main/run_gseapy/ranking_metrics"
                        },
                        {
                            "source": "#main/read_counts_file",
                            "id": "#main/run_gseapy/read_counts_file"
                        },
                        {
                            "source": "#main/seed",
                            "id": "#main/run_gseapy/seed"
                        },
                        {
                            "source": "#main/threads",
                            "id": "#main/run_gseapy/threads"
                        }
                    ],
                    "out": [
                        "#main/run_gseapy/enrichment_report",
                        "#main/run_gseapy/enrichment_plots",
                        "#main/run_gseapy/enrichment_heatmaps",
                        "#main/run_gseapy/stdout_log",
                        "#main/run_gseapy/stderr_log"
                    ],
                    "id": "#main/run_gseapy"
                }
            ],
            "label": "GSEApy - Gene Set Enrichment Analysis in Python",
            "doc": "GSEAPY: Gene Set Enrichment Analysis in Python\n==============================================\n\nGene Set Enrichment Analysis is a computational method that determines whether an a priori\ndefined set of genes shows statistically significant, concordant differences between two\nbiological states (e.g. phenotypes).\n\nGSEA requires as input an expression dataset, which contains expression profiles for multiple samples.\nWhile the software supports multiple input file formats for these datasets, the tab-delimited GCT format\nis the most common. The first column of the GCT file contains feature identifiers (gene ids or symbols in\nthe case of data derived from RNA-Seq experiments). The second column contains a description of the feature;\nthis column is ignored by GSEA and may be filled with \u201cNA\u201ds. Subsequent columns contain the expression\nvalues for each feature, with one sample's expression value per column. It is important to note that there\nare no hard and fast rules regarding how a GCT file's expression values are derived. The important point is\nthat they are comparable to one another across features within a sample and comparable to one another\nacross samples. Tools such as DESeq2 can be made to produce properly normalized data (normalized counts)\nwhich are compatible with GSEA.",
            "id": "#main",
            "http://schema.org/name": "GSEApy - Gene Set Enrichment Analysis in Python",
            "http://schema.org/alternateName": "GSEApy - Gene Set Enrichment Analysis in Python",
            "http://schema.org/downloadUrl": "https://raw.githubusercontent.com/datirium/workflows/master/workflows/gseapy.cwl",
            "http://schema.org/codeRepository": "https://github.com/datirium/workflows",
            "http://schema.org/license": "http://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/isPartOf": {
                "class": "http://schema.org/CreativeWork",
                "http://schema.org/name": "Common Workflow Language",
                "http://schema.org/url": "http://commonwl.org/"
            },
            "http://schema.org/creator": [
                {
                    "class": "http://schema.org/Organization",
                    "http://schema.org/legalName": "Cincinnati Children's Hospital Medical Center",
                    "http://schema.org/location": [
                        {
                            "class": "http://schema.org/PostalAddress",
                            "http://schema.org/addressCountry": "USA",
                            "http://schema.org/addressLocality": "Cincinnati",
                            "http://schema.org/addressRegion": "OH",
                            "http://schema.org/postalCode": "45229",
                            "http://schema.org/streetAddress": "3333 Burnet Ave",
                            "http://schema.org/telephone": "+1(513)636-4200"
                        }
                    ],
                    "http://schema.org/logo": "https://www.cincinnatichildrens.org/-/media/cincinnati%20childrens/global%20shared/childrens-logo-new.png",
                    "http://schema.org/department": [
                        {
                            "class": "http://schema.org/Organization",
                            "http://schema.org/legalName": "Allergy and Immunology",
                            "http://schema.org/department": [
                                {
                                    "class": "http://schema.org/Organization",
                                    "http://schema.org/legalName": "Barski Research Lab",
                                    "http://schema.org/member": [
                                        {
                                            "class": "http://schema.org/Person",
                                            "http://schema.org/name": "Michael Kotliar",
                                            "http://schema.org/email": "mailto:misha.kotliar@gmail.com",
                                            "http://schema.org/sameAs": [
                                                {
                                                    "$import": "#0000-0002-6486-3898"
                                                }
                                            ]
                                        }
                                    ]
                                }
                            ]
                        }
                    ]
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "https://schema.org/version/latest/schema.rdf"
    ],
    "$namespaces": {
        "s": "http://schema.org/"
    }
}
